How To
======

This section of the documentation aims to provide guided examples for users to familiarize themselves with the use of Queenbee to create reusable recipe templates and store them.

Pre-Flight Check
----------------

Tools
^^^^^
It will be easier to follow these guides if you have a few tools installed on your computer.

- A Code Editor (we like VSCode but you can use whatever you want of course!)
- Python 3.6 or above (`installation <https://www.python.org/downloads/>`_)
- Queenbee CLI (`installation </cli>`_)

Knowledge
^^^^^^^^^
New users will benefit from being familiar with the following:

- Terminals/command prompts to debug potential issues
- YAML (`official spec <https://yaml.org/spec/1.2/spec.html>`_ or a `human friendly explainer <https://rollout.io/blog/yaml-tutorial-everything-you-need-get-started/>`_)
- `Docker <https://www.docker.com/>`_ and containers are in general helpful but is not essential

Guides
------
.. toctree::
   :maxdepth: 1

   plugin
   recipe
   repository-create
   repository-manage
